@@ -1,4 +1,5 @@
-#' telegram.bot
+
+#' Develop a Telegram Bot with R
 #'
 #' Provides a pure interface for the \href{http://core.telegram.org/bots/api}{Telegram Bot API}.
 #' In addition to the pure API implementation, it features a number of
@@ -15,18 +16,32 @@
 #'         class \code{\link{Bot}} to the programmer, so they can focus on coding the bot.
 #'         Its purpose is to receive the updates from Telegram and to deliver them to said
 #'         dispatcher.}
+#'     \item{\code{\link{Bot}}}{This object represents a Telegram Bot.}
 #'     \item{\code{\link{Dispatcher}}}{This class dispatches all kinds of updates to its
 #'         registered handlers.}
 #'     \item{\code{\link{Handler}}}{The base class for all update handlers.}
-#'     \item{\code{\link{Bot}}}{This object represents a Telegram Bot.}
 #' }
 #' 
+#' @examples \dontrun{
+#' library(telegram.bot)
+#' 
+#' start <- function(bot, update){
+#'   bot$sendMessage(chat_id = update$message$chat_id,
+#'                   text = sprintf("Hello %s!", update$message$from$first_name))
+#' }
+#' 
+#' updater <- Updater("TOKEN") + CommandHandler("start", start)
+#' 
+#' updater$start_polling() # Send '/start' to the bot
+#' }
 #' @name telegram.bot
 #' @docType package
+#' @keywords internal
 #' @importFrom R6 R6Class
 #' @importFrom httr POST
 #' @importFrom httr content
 #' @importFrom httr stop_for_status
 #' @importFrom httr upload_file
 #' @importFrom jsonlite toJSON
-NULL
+#' @importFrom curl curl_download
+"_PACKAGE"
